==> vokoscreen_1.9.6.orig.tar.gz: vokoscreen-1.9.6/language/vokoscreen_nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mail laatste Video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mail een of meer geselecteerde video &apos;s</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Zenden</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>U vindt de video als bijlage</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selecteer een of meer bestanden</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Geen rand</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Apparaat is bezig</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Muiscursor niet opnemen</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video map</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Speler</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen in taakbalk als opname start</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Verzenden</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Opnametijd</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grootte in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grootte van scherm opname</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Instellingen fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Open direktory</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Speel laatste Video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Stuur Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Apparaat %1 is bezig</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.2.0.orig.tar.gz: vokoscreen-2.2.0/language/vokoscreen_nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Apparaat is bezig</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mail laatste Video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mail een of meer geselecteerde video &apos;s</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Verzenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>U vindt de video als bijlage</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selecteer een of meer bestanden</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Apparaat is bezig</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Muiscursor niet opnemen</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video map</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Speler</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen in taakbalk als opname start</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Verzenden</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Opnametijd</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grootte in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grootte van scherm opname</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Instellingen fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Open direktory</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Speel laatste Video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Stuur Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
